📦 Note_search 用户手册
=======================

# 安装

```python
pip install Note_search
```

## 需求
为了解决用户查找自己笔记的需求，希望在短时间内寻找到自己需要的笔记。


## 难点
1. 文件路径处理
2. 各个文件读取
3. 汇总数据储存方法，csv,xlsx,sql
4. 汇总存储时数据格式
5. 启动程序时提问是都更新索引数据
6. 检索数据时返回数据结果格式： “文件名称：path + 是否自动打开文件，是否快速获取笔记简介，笔记所处行数”

## 预期功能
### 一、交互

1. 获取用户输入
    2. 获取用户要查询的路径
        3. 新路径
        4. 默认路径
    3. 获取用户要查询的内容

### 二、结果

1. 查询到结果则返回结果「该文件路径」和部分内容「前100字」
    2. 并提示是否自动打开文件
    3. 打开错误则返回报错信息
2. 无结果则返回提示
3. 询问是否继续查询
    4. 继续查询输入 1
    5. 结束查询输入 0

### 三、特殊功能

1. 每次程序启动询问是否要生成新的检索文件「意为："生成数据库"」——update
    2. up:更新
    3. noup:不更新

### 扩展:

1. 简易文件下载器
2. GUI or web



